# Nile verifier plugin

Plugin for [Nile](https://github.com/OpenZeppelin/nile) to verify contracts on [starkscan.co](https://starkscan.co).

> ## ⚠️ WARNING! ⚠️
>
> This repo contains highly experimental code.
> Expect rapid iteration.
> **Use at your own risk.**

## Installation

1. Install [Poetry](https://python-poetry.org/docs/#installation)
2. Install dependencies: `poetry install`

## License

MIT
